#!/bin/sh
. ./build.conf

export LANG="en_US.UTF-8"

if [ "$1" = "" ]; then
    echo "Usage: ./build sdd sde sff ...."
    exit 0
fi

if [ ! "`echo "a a" | tr -cd [:graph:]`" = "aa" ]; then
    echo -e "\\033[0;31mERROR: '"`which tr`"' utility not working correctly!"
    echo -en "\\033[1;33m"
    exit 1
fi

echo "Mapping flash disks: "$@". ALL IS OK?"
read question
question="YES"
if [ "$question" != "YES" ]; then
    echo "Exiting"
    exit 0
fi

for i in "$@"; do
    echo "Stating programing $i"
    umount /dev/${1}1 >/dev/null 2>&1
    fdisk /dev/$1 <./files/fdisk.tpl >/dev/null 2>&1
    mkfs.ext2 -cF /dev/$1"1"
    sleep 2
    cat ./files/mbr.bin >/dev/$1
    echo "mbr copy ..."
    

    echo "Copying files..."
    mount /dev/$1"1" ./tmp/
    if [ "$?" -ne "0" ]; then
	echo "Mounting $i"1" ERROR"
	exit 1
    fi

    hdparm -i /dev/${1} >/dev/null 2>&1                                                                                                              
    if [ "$?" = "0" ]; then                                                                                                                     
	# getting other parameters from device                                                                                                  
	MOD=`hdparm -i /dev/${1} 2>&1 |grep Model | awk -F"Model=" '{print $2}' |awk -F',' '{print $1}'`                                             
	FWR=`hdparm -i /dev/${1} 2>&1 |grep FwRev | awk -F"FwRev=" '{print $2}' |awk -F',' '{print $1}'`                                             
	SER=`hdparm -i /dev/${1} 2>&1 |grep SerialNo | awk -F"SerialNo=" '{print $2}' |awk -F',' '{print $1}'`                                       
	BUF=`hdparm -i /dev/${1} 2>&1 |grep BuffSize | awk -F"BuffSize=" '{print $2}' |awk -F',' '{print $1}'`                                       
	BID=`blkid /dev/${1}1 | awk -F"UUID=" '{print $2}' | awk '{print $1}'| tr -d "\""`                                                         
	SIZ=`fdisk -l /dev/${1} | grep "Disk " |awk -F"bytes" '{print $1}' | awk -F", " '{print $2}'`                                                 
	
	if [ "${BUF}" = "unknown" ]; then
	    # creating SHA256 checksum for SSD disk
	    SERIAL=`echo "${SIZ}${BID}" | tr -cd [:graph:] |sha256sum | awk '{print $1}'`                                                                              
        else
	    # creating SHA256 checksum all aerial data
	    SERIAL=`echo "${MOD}${FWR}${SER}${BUF}${BID}" | tr -cd [:graph:] |sha256sum | awk '{print $1}'`
	fi
    else                                                                                                                                        
	SIZ=`fdisk -l /dev/${1} | grep "Disk " |awk -F"bytes" '{print $1}' | awk -F", " '{print $2}'`                                                 
	BID=`blkid /dev/${1}1 | awk -F"UUID=" '{print $2}' | awk '{print $1}'| tr -d "\""`                                                         
                                                                                                                                            
        # creating SHA256 checksum for small serial data                                                                                                          
	SERIAL=`echo "${SIZ}${BID}" | tr -cd [:graph:] |sha256sum | awk '{print $1}'`                                                                              
    fi                                                                                                                                          
    ssh -o StrictHostKeychecking=no -p 9930 sign@mgmd1.skysend.ru "$SERIAL" | base64 -d >$insignkey
    if [ "$?" -ne "0" ]; then                                                                                                               
	echo "Getting sign error!!!"
	exit 1                                                                                                                              
    fi    

# generating sha256 from boot UUID for first start
    echo $BID |sha256sum | awk '{print $1}' >$firststart

    if [ ! -s $insignkey ]; then
	echo "Error while generating system digital signatures and keys. Wrong password?"
	exit 1
    else
	echo "Generating openssl system sign and keys completed..."
    fi

    cp -fr ./system/* ./tmp/
    sync

    ./files/extlinux -i ./tmp >/dev/null 2>&1
    if [ "$?" -ne "0" ]; then
	extlinux -i ./tmp >/dev/null 2>&1
	    if [ "$?" -ne "0" ]; then
		    echo -en "\\033[1;31m ERROR!!! BOOTLOADER NOT INSTALL!!!! Exiting!"
		    echo
		    echo -en "\\033[1;32m 	WARNING! Creation of the boot record on device /dev/$1"1" failed...
    Probably you didn't set the loader of a kernel of Extlinux.
    To install a packet execute:
    for OS Linux Ubuntu  - apt-get install extlinux
    for OS Linux Mandriva - urpmi syslinux"
	    exit 1
	    fi
    fi

    e2label /dev/${1}1 FASTSYS4
#    cat ./files/mbr.bin >/dev/$1
#    echo "mbr copy ..."

    md5sum -c ./files/all.md5
    if [ "$?" -ne "0" ]; then
	echo -en "\\033[1;31m ERROR!!! Flash IS BAD!!!! MD5 SUMM NOT MATCHES!!! Exiting!"
	echo
	exit 1
    fi

    umount ./tmp
    echo -en "\\033[1;32m Programming $i successful completed!"
    echo
done
